/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef LPQHELPER_H
#define LPQHELPER_H

#include <QtCore/QList>
#include <QtCore/QObject>

class KMJob;

class LpqHelper : public QObject
{
	Q_OBJECT

public:
	LpqHelper(QObject *parent = 0);
	~LpqHelper();

	void listJobs(QList<KMJob*>& jobs, const QString& prname, int limit = 0);

protected:
	KMJob* parseLineLpr(const QString&);
	KMJob* parseLineLPRng(const QString&);

private:
	QString		m_exepath;
};

#endif
